@@ -75,7 +75,7 @@ static char *licensefiles[] = { "HEAD:LICENSE", "HEAD:LICENSE.md", "HEAD:COPYING
 static char *license;
 static char *readmefiles[] = { "HEAD:README", "HEAD:README.md" };
 static char *readme;
-static long long nlogcommits = -1; /* < 0 indicates not used */
+static long long nlogcommits = -1; /* -1 indicates not used */
 
 /* cache */
 static git_oid lastoid;
@@ -832,11 +832,11 @@ writelog(FILE *fp, const git_oid *oid)
 	git_oid id;
 	char path[PATH_MAX], oidstr[GIT_OID_HEXSZ + 1];
 	FILE *fpfile;
+	size_t remcommits = 0;
 	int r;
 
 	git_revwalk_new(&w, repo);
 	git_revwalk_push(w, oid);
-	git_revwalk_simplify_first_parent(w);
 
 	while (!git_revwalk_next(&id, w)) {
 		if (cachefile && !memcmp(&id, &lastoid, sizeof(id)))
@@ -850,19 +850,19 @@ writelog(FILE *fp, const git_oid *oid)
 
 		/* optimization: if there are no log lines to write and
 		   the commit file already exists: skip the diffstat */
-		if (!nlogcommits && !r)
-			continue;
+		if (!nlogcommits) {
+			remcommits++;
+			if (!r)
+				continue;
+		}
 
 		if (!(ci = commitinfo_getbyoid(&id)))
 			break;
 
-		if (nlogcommits < 0) {
+		if (nlogcommits != 0) {
 			writelogline(fp, ci);
-		} else if (nlogcommits > 0) {
-			writelogline(fp, ci);
-			nlogcommits--;
-			if (!nlogcommits && ci->parentoid[0])
-				fprintf(fp, "%16.16s  More commits remaining [...]\n", "");
+			if (nlogcommits > 0)
+				nlogcommits--;
 		}
 
 		if (cachefile)
@@ -885,6 +885,12 @@ err:
 	}
 	git_revwalk_free(w);
 
+	if (nlogcommits == 0 && remcommits != 0) {
+		fprintf(fp, "%16.16s  "
+		        "%zu more commits remaining, fetch the repository\n",
+		        "", remcommits);
+	}
+
 	return 0;
 }
 
@@ -966,7 +972,6 @@ writeatom(FILE *fp, int all)
 	if (all) {
 		git_revwalk_new(&w, repo);
 		git_revwalk_push_head(w);
-		git_revwalk_simplify_first_parent(w);
 		for (i = 0; i < m && !git_revwalk_next(&id, w); i++) {
 			if (!(ci = commitinfo_getbyoid(&id)))
 				break;
